@@ -1,11 +1,11 @@
 /*
  *
- *  This file is part of MUMPS 5.0.1, released
- *  on Thu Jul 23 17:08:29 UTC 2015
+ *  This file is part of MUMPS 5.2.1, released
+ *  on Fri Jun 14 14:46:05 UTC 2019
  *
  *
- *  Copyright 1991-2015 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
- *  University of Bordeaux.
+ *  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
  *  released under the CeCILL-C license:
@@ -17,7 +17,7 @@
 #ifndef MUMPS_C_TYPES_H
 #define MUMPS_C_TYPES_H
 
-#include <inttypes.h>
+#include <stdint.h>
 #ifdef INTSIZE64
 #define MUMPS_INT int64_t
 #else
@@ -46,7 +46,8 @@ typedef struct {double r,i;} mumps_double_complex;
 #ifndef mumps_ftnlen
 /* When passing a string, what is the type of the extra argument
  * passed by value ? */
-# define mumps_ftnlen MUMPS_INT
+/* # define mumps_ftnlen MUMPS_INT */ /* ssg */
+# define mumps_ftnlen long int
 #endif
 
 
